#
# spec file for package zipios
#
# Copyright (c) 2023 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver  2
Name:           zipios
Version:        2.3.2
Release:        1.5
Summary:        C++ Library for Reading and Writing Zip Files
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://github.com/Zipios/Zipios
Source0:        https://github.com/Zipios/Zipios/archive/refs/tags/%{version}.tar.gz#/zipios-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE zipios-docpath.patch aloisio@gmx.com -- use correct package path
Patch0:         zipios-docpath.patch
# PATCH-FIX-UPSTREAM
Patch1:         https://github.com/Zipios/Zipios/commit/60b8c7bf79e6a4458e4c0d78f5fb14a81f4feac7.patch#/fix_cstdint_include.patch
BuildRequires:  cmake >= 3.10.2
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz-gd
BuildRequires:  gcc-c++
BuildRequires:  cmake(Catch2)
BuildRequires:  pkgconfig(zlib)

%description
Zipios is a java.util.zip-like C++ library for reading and writing Zip files.
Access to individual entries is provided through standard C++ iostreams. A
simple read-only virtual file system that mounts regular directories and zip
files is also provided.

%package devel
Summary:        Zipios Header Files
Group:          Development/Libraries/C and C++
Requires:       libzipios%{so_ver} = %{version}
Requires:       pkgconfig(zlib)
Suggests:       %{name}-devel-doc

%description devel
Header files for zipios development.

%package devel-doc
Summary:        Zipios API documentation
Group:          Documentation/HTML
# Package split
Provides:       %{name}-devel:%{_defaultdocdir}/zipios
Conflicts:      %{name}-devel < 2.2.6
BuildArch:      noarch

%description devel-doc
API documentation for zipios.

%package -n libzipios%{so_ver}
Summary:        C++ Library for Reading and Writing Zip Files
Group:          System/Libraries

%description -n libzipios%{so_ver}
Zipios is a java.util.zip-like C++ library for reading and writing Zip files.
Access to individual entries is provided through standard C++ iostreams. A
simple read-only virtual file system that mounts regular directories and zip
files is also provided.

%prep
%autosetup -p1 -n Zipios-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install
# Remove the fairly pointless metainfo for a library
rm %{buildroot}%{_datadir}/metainfo/zipios.metainfo.xml

%fdupes %{buildroot}%{_defaultdocdir}

%post -n libzipios%{so_ver} -p /sbin/ldconfig
%postun -n libzipios%{so_ver} -p /sbin/ldconfig

%files devel
%license COPYING
%doc AUTHORS NEWS README.md TODO.md
%{_bindir}/appendzip
%{_bindir}/dosdatetime
%{_bindir}/zcrc32
%{_bindir}/zipdir
%{_bindir}/zipios
%{_datadir}/cmake/ZipIos
%{_includedir}/zipios
%{_libdir}/libzipios.so
%{_mandir}/man3/%{name}*.3%{?ext_man}

%files devel-doc
%doc %{_defaultdocdir}/zipios

%files -n libzipios%{so_ver}
%{_libdir}/libzipios.so.*

%changelog
* Sat Dec 30 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.3.2:
  * Bugs:
    + As suggested, use argv[2] when ent is nullptr (#42).
    + Fixed an issue with empty files to avoid error.
    + Missed adding the signature to the last entry.
    + Fixed two operator = () which improperly returned a const &.
    + Really auto-init m_zs.
    + Require that chdir() & truncate() return 0.
    + Bumped the version to 2.3 since the CRC32 computation bug was
    a pretty major fix (#38).
    + Correctly clear the m_checked flag on a change of the FilePath.
    + Fixed a Logical OR (|| instead of |).
    + Fixed two ISO-8851-1 characters.
    + Removed the inverted question mark.
    + Fixed path to BUILD folder in ./mk script.
  * New Features / Enhancements
    + Extended public interface.
    + Added support for an std::istream when creating a ZipFile
    object.
    + Added support for a StreamEntry when creating a zip file.
    + Replaced new ... with std::make_shared<>() where possible.
    + Updated CMakeLists.txt (clean ups).
    + Removed the -std=c++17 option. I don't need it and it's
    better without.
    + Implemented the big endian version of the
    dosdatetime_convert_t union.
    + Added casts for signed/unsigned comparisons.
    + Added a function to compute CRC32 of local disk files.
    + Added the clear() and empty() functions to the FilePath class.
    + Use clear() instead of setting string to "".
    + Added support for -v (verbose) to the ./mk script.
  * Documentation
    + Made the search of the Doxygen tools quieter by default.
    + Added a note about the root branch renaming. It is "main" now.
    + Added a few comments (missing docs).
    + Ran ispell to fix the docs a bit.
    + Corrected links in README.md (especially use the https protocol)
    + Changed the o umlaut to use UTF-8.
  * Packaging (included Debian)
    + Changed Debian release name to bionic and then jammy.
    + Updated the compat to v10.
    + Removing the multiarch-support dependency. It's only for
    amd64 at the moment.
    + Remove dependency on old catch package. We now use
    snapcatch2.
  * Tests
    + Upgraded the tests to catch2 v3.x.
    + Renamed the tests catch_<name>.cpp.
    + Renamed the file with the main() function catch_main.cpp/hpp.
    + Enhanced the test of the project version.
    + Make use of the --tmp-path and --source-path of the new
    snapcatch2 main().
    + Fixed test verifying DOS timestamps with +/- 1 hour (ugly but
    it works).
    + Removed the '&' in a CATCH_REQUIRE_THROWS_AS().
    + Fixed the include and library linking for the tests.
    + Added CATCH_END_SECTION() everywhere.
    + Prepended CATCH_... to all the macros so they compile with
    the newer version.
    + Properly indent the test CMakeLists.txt file.
    + Removed the cmake_minimum_required(). It's only required in
    the main CMakeLists.txt.
    + Verify the versions in the tests to be more sure I catch
    discrepancies.
    + Added a new test to make sure issue #38 was fixed.
    + Made tests delete files upfront too (in case it breaks part
    way in a previous run).
  * Add fix_cstdint_include.patch
* Tue Aug  8 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.2.6:
  * Applied a few fixes to avoid some warnings when compiling in
    32 bits.
  * Commented out tests which verify dates outside of the 32 bit
    range (i.e. time_t is a 32 bit signed integer on a 32 bit OS).
  * Fixed the docs Bugs and Links and Issue Sections.
  * Removed some ++ from Zipios because the name changed and we
    removed the ++.
  * Applied most of pull request 30, added the metainfo.xml file.
  * Applied https://github.com/Zipios/Zipios/pull/34 (remove path
    from all filenames)
- Update to version 2.2.5:
  * Applied https://github.com/Zipios/Zipios/pull/31
    (corrections to comments as in spelling/grammar errors)
- Update to version 2.2.4:
  * Applied fix to some tests so they compile with g++ 8.3.x
- Update to version 2.2.3:
  * Added in=C++ to the MAPPING_EXTENSION.
  * Updated the doxy file to 1.8.11.
  * Removed one more UTF-8 emdash character.
  * Made a few changes in link with the website and CVE-2019-13453
    in the old zipios library.
  * Added a favicon for the website.
- Update to version 2.2.2:
  * Fixed the FindCatch.cmake, the REQUIRED was not properly tested.
- Update to version 2.2.1:
  * Fixed the "DirectoryEntry for a valid directory" test as the
    FileEntry object saves a Unix timestamp as a time_t and
    therefore with a full range precision. (#29)
- Update build dependencies
- Clean up spec file
- Drop obsolete zipios-use_PIE.patch
- Split API documentation from devel package
* Sat May 18 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.2.0
  * As per [issue #28 on
    Github](https://github.com/Zipios/Zipios/issues/28),
    there was a discrepancy in licenses because of the dostime.c
    and dostime.h files.
    These two files were removed and replaced by a DOSDateTime
    class instead.
    It's all C++ and uses a structure with field to convert the
    data as required.
  * The license was also updated and copyright file fixed up to
    match the newer version.
- Renamed package files to match package name
- Added zipios-docpath.patch and zipios-use_PIE.patch
- Spec cleanup
* Thu Jul  7 2016 adrian@suse.de
- update to version 2.1.1
  - obsoletes all patches thanks to cmake and fixed code
  - c++11 api now
  - so version jumps to 2
- rename from zipios++ to zipios, following upstream
* Tue Mar 20 2012 asterios.dramis@gmail.com
- Added a patch (ptrdiff.patch) to fix compilation error "error: 'ptrdiff_t'
  does not name a type" (taken from Debian).
- Spec file updates:
  * Renamed spec file from libzipios0 to zipios++ (to be the same as the
    package name).
  * Renamed libzipios0-devel to zipios++-devel and added the necessary
    Provides/Obsoletes entries for libzipios0-devel.
  * Changes based on spec-cleaner run.
  * Changed License: to LGPL-2.1+.
  * Disabled compilation of static library.
* Sat Jan 28 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Sun May  8 2011 andrea@links2linux.de
- New Package
